package cn.fw.hestia.sdk.params;

import lombok.Data;
import lombok.ToString;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.Map;

/**
 * 模板消息param
 *
 * 模板消息样例：
 *
 * {{first.DATA}}
 * 变更类型：{{keyword1.DATA}}
 * 变更结果：{{keyword2.DATA}}
 * {{remark.DATA}}
 *
 *   示例：
 * 尊敬的客户，您的业务状态已经发生变更 变更详情如下：
 * 变更类型：组局地点
 * 变更结果：由清水河改为滨江
 * 如有疑问，请拨打客服电话
 *
 * @author kurisu
 */
@Data
@ToString
public class TemplateMessageParam {
    /**
     * 会员id
     */
    @NotNull(message = "会员id不能为空")
    private Long memberId;
    /**
     * 标题内容 对应「first」字段
     */
    @NotBlank(message = "标题内容不能为空")
    private String title;
    /**
     * 备注
     */
    private String remark;
    /**
     * 变更类型
     */
    @NotBlank(message = "变更类型不能为空")
    private String changeType;
    /**
     * 变更结果
     */
    @NotBlank(message = "变更结果不能为空")
    private String changeResult;
    /**
     * 如需跳转小程序，则是小程序页面路径
     */
    private String path;
    /**
     * 跳转小程序所携带的参数
     */
    private Map<String, String> paramMap;
}
